# Generated by h2py from db.h

RET_ERROR = -1
RET_SUCCESS = 0
RET_SPECIAL = 1
MAX_PAGE_NUMBER = 0xffffffff
MAX_PAGE_OFFSET = 65535
MAX_REC_NUMBER = 0xffffffff
R_CURSOR = 1
__R_UNUSED = 2
R_FIRST = 3
R_IAFTER = 4
R_IBEFORE = 5
R_LAST = 6
R_NEXT = 7
R_NOOVERWRITE = 8
R_PREV = 9
R_SETCURSOR = 10
R_RECNOSYNC = 11
DB_LOCK = 0x20000000
DB_SHMEM = 0x40000000
DB_TXN = 0x80000000
DB_LOCK = 0x2000
DB_SHMEM = 0x4000
DB_TXN = 0x8000
BTREEMAGIC = 0x053162
BTREEVERSION = 3
R_DUP = 0x01
HASHMAGIC = 0x061561
HASHVERSION = 2
R_FIXEDLEN = 0x01
R_NOKEY = 0x02
R_SNAPSHOT = 0x04

